# DB Pagination

The [Pagination][fluid.db.Pagination] class is a tool for managing paginated rows from the database.

It requires the `db` extra to be installed:

```bash
pip install aio-fluid[db]
```

It can be imported from `fluid.db`:

```python
from fluid.db import Pagination, Search
```

::: fluid.db.Pagination


::: fluid.db.Search
